#####
BRIEF
#####

binnenkort stemt de Tweede Kamer over de Wet verplichte GGZ en ik wil u en de Tweede Kamer hierover informeren.

Mishandeling van medicijnen is strafbaar in het Wetboek van Strafrecht:

* Artikel 300.4 Met mishandeling wordt gelijkgesteld opzettelijke benadeling van de gezondheid.

* Artikel 304.3 indien het misdrijf wordt gepleegd door toediening van voor het leven of de gezondheid schadelijke stoffen.

Behandeling met antipsychotica is opzettelijke benadeling van de gezondheid gepleegd door toediening van voor het leven of de gezondheid schadelijke stoffen, om met die benadeling van de gezondheid te proberen de psychotische symptomen te verminderen.

kortom:

Antipsychotica brengen schade toe aan de hersenen in de hoop met toebrenging van die schade de psychotische symptomen te verminderen. De schade die men toebrengt is opzettelijk en daarmee is het mishandeling.

Op basis van een wettelijk voorschrift  is deze mishandeling niet strafbaar:

* Artikel 42 Niet strafbaar is hij die een feit begaat ter uitvoering van een wettelijk voorschrift

Een wet die tot behandeling verplicht en op die manier de mishandeling niet strafbaar maakt, maakt niet dat men geen misdrijf pleegt. Er word nog steeds een misdrijf gepleegd, waar men schuldig aan is en wat direct gestopt dient te worden. Het is de plicht van het Openbaar Ministerie om op te treden als er strafbare feiten worden gepleegd, ook als vervolging tot niet strafbaar leid, met als argument dat als het plegen van mishandeling niet gestopt word er geen einde komt aan de mishandeling.

Met het aannemen van de Wet verplichte Geestelijke Gezondheidzorg maakt de Tweede Kamer de behandeling met antipsychotica verplicht en daarmee mishandeling gepleegd door het toedienen van voor het leven en de gezondheid schadelijke stoffen niet strafbaar. De Tweede Kamer maakt zich hiermee schuldig aan het op grote schaal mogelijk maken van mishandeling.

De Wet verplichte GGZ dient u daarom niet aan te nemen en om huidige mishandelingen te stoppen dient u terstond het Openbaar Ministerie ontvankelijk te maken voor elke patient die zijn mishandeling door de strafrechter gestopt wil zien worden.

KAMER
=====

 Geachte heer Aardema,

ik wil u graag informeren dat uw commissies van VWS en J&V geinformeerd zijn dat de medcijnen gebruikt in de gedwongen zorg waar uw wet een wettelijk voorschrift voor gaat bieden gif blijken te zijn.

Er is bewijs dat de medcijnen gebruikt in de GGZ gif zijn, bewijs dat geleverd word door het ECHA agentschap van de Europeese Unie, wat bij houd welke chemicalien een gevaar zijn of niet. De ECHA laat bedrijven die stoffen willen transporteren testen doen wat hun dodelijkheid betreft, de zogenoemde LD-50 tests. Aan de hand van deze tests beoordeelt men dan of een stof onschadelijk, schadelijk, gif of dodelijk zijn. Deze tests resulteren in labels die men moet gebruiken als men de stof transporteert.


Voor de stof haloperiodol, de werkzame stof in Haldol, ziet u hier de waarschuwingen die te vinden zijn op https://echa.europa.eu/substance-information/-/substanceinfo/100.000.142

Haldol is het meest gebruikt medicijn als "nood medicatie" in de GGZ, een klassiek antipsychoticum.


bewijs dat haldol gif is


Zoals u ziet is haloperidol geclassificeerd als "toxic as swallowed" en is een doodskop met beenderen noodzakelijk als men deze stof wil vervoeren.

Men gebruikt in de GGZ dus geen medicijnen die geen schade kunnen, maar een stof die giftig is als men hem inneemt.

De medicatie die u in uw wet toestaat om gedwongen toegedient te kunnen worden zijn gif en niet zoals men beweerd een medicijn dat geen schade kan.

Deze wet aannemen in de wetenschap dat het hier gif betreft maakt dat uw wettelijke voorschrift gebruikt word voor giftoedieningen en niet voor behandeling met medicijnen die geen schade kunnen.

U zekert hier de straffeloosheid voor deze gif toedieningen als u niet ook zorgt dat de medicatie waar uw wet aan refereert ook niet daadwerkelijk medicijnen zijn die geen schade kunnen.

Ik hoop dat u de wetenschap dat het hier gif betreft en niet medicatie zult gebruiken om de WvGGZ niet aan te nemen, hij word nu gebruikt in een poging gif toedieningen te legaliseren, te voorzien van een wettelijk voorschrift.


Hoogachtend,


Bart Thate


p.s. de commissies VWS en J&V van uw kamer zijn ook geinformeerd maar uw persoonlijk ook op de hoogte brengen voordat men hier over stemt verdient de voorkeur.

